# X509CertificateSpec

A X509CertificateSpec
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**certificate** | **str** | The issued x509 certificate, formatted as PEM. | [optional] 
**csr_id** | **str** | The CertSigningReq id associated with this certificate | 
**org_id** | **str** | Unique identifier | 
**message** | **str** | A system message associated with the reason.  | [optional] 
**reason** | [**CSRReasonEnum**](CSRReasonEnum.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


